/*
 * Speichern und laden der Adresse (IP und Port) an die das 'AliveSignal' gesendet werden soll
 */

void saveAliveConfig(IPAddress ip, int port, int intervall, String fileName)
// fileName Format "\[fileName]"
{
  //save the custom parameters to FS
  Serial.println("saving Alive config");
  DynamicJsonBuffer jsonBuffer;
  JsonObject& json = jsonBuffer.createObject();
  json["aliveIp"] = ip.toString();
  json["alivePort"] = port;
  json["aliveIntervall"] = intervall;

  File configFile = SPIFFS.open(fileName, "w");
  if (!configFile) {
    // Serial.println("failed to open config file for writing");
  }

  json.printTo(Serial);
  json.printTo(configFile);
  configFile.close();
  //end save

}

void loadAliveConfig(IPAddress& ip, int& port, int& intervall, String fileName)
// fileName Format "\[fileName]"
{
    if (SPIFFS.begin())
    {
      if (SPIFFS.exists(fileName))
      {
        File configFile = SPIFFS.open(fileName, "r");
        if (configFile)
        {
          size_t size = configFile.size();
          // Allocate a buffer to store contents of the file.
          std::unique_ptr<char[]> buf(new char[size]);
  
          configFile.readBytes(buf.get(), size);
          DynamicJsonBuffer jsonBuffer;
          JsonObject& json = jsonBuffer.parseObject(buf.get());
          json.printTo(Serial);

          if (json.success()) {
  
            String tempStr = json["alivePort"];
            port = tempStr.toInt();
            const char* tempIp = json["aliveIp"];
            ip.fromString(tempIp);
            String tempStrIntervall = json["aliveIntervall"];
            intervall = tempStrIntervall.toInt();
  
          } else {
            // Serial.println("failed to load json config");
          }
        }
      }
    }
}

// Speichern per HTTP übergebenen Werte für die AliveSignal Konfiguration
void httpSaveAliveConfig()
{
  String response = "";
  String temp = "";
  IPAddress ipa;
  int tempPort;
  int tempIntervall;

  /* ------------------------------------------------------------------------------*/
  // prüfen auf "IP-Adresse"
  if (server.hasArg("ip")) {
      // ip auslesen
      temp = server.arg("ip");
      response += "neue IP-Adresse = ";
      response += temp;
      response += "<br>";
      // Serial.print("neue IP-Adresse = ");
      // Serial.println(temp);
      if (!ipa.fromString(temp))
      {
        response += "Fehler in IP-Adresse";
      }
  }

  /* ------------------------------------------------------------------------------*/
  // prüfen auf "port"
  if (server.hasArg("port")) {
      // port auslesen
      temp = server.arg("port");
      response += "neuer Port = ";
      response += temp;
      response += "<br>";
      // Serial.print("neuer Port = ");
      // Serial.println(temp);
      tempPort = temp.toInt();    // Speichern als Int
  }

  /* ------------------------------------------------------------------------------*/
  // prüfen auf "intervall"
  if (server.hasArg("intervall")) {
      // intervall auslesen
      temp = server.arg("intervall");
      response += "neues Intervall = ";
      response += temp;
      response += "<br>";
      // Serial.print("neues Intervall = ");
      // Serial.println(temp);
      tempIntervall = temp.toInt();    // Speichern als Int
  }

  saveAliveConfig(ipa, tempPort, tempIntervall, aliveConfigFile);
  
  response += "Saved Configuration<br>";
  server.send ( 200, "text/html", response);

  // noch mal die Konfiguration laden, damit diese auch gleich aktiv wird.
  loadAliveConfig(aliveIp, alivePort, aliveIntervall, aliveConfigFile);

}

